@@ -2,7 +2,8 @@ use strict;
 use Getopt::Long;
 my $release = 'blib/';
 my $dir     = 'httpdocs/';
-my $result  = GetOptions("release=s" => \$release, "readdir=s" => \$dir,);
+my $path    = '.';
+my $result  = GetOptions("release=s" => \$release, "readdir=s" => \$dir, "htpath=s" => \$path,);
 system("mkdir -p $release") unless -e $release;
 &change($dir);
 
@@ -28,5 +29,16 @@ sub change {
                 }
         }
 }
+chmod 0644, "blib/lib/HTML/Menu/TreeView.pm";
+open(EDIT, '+<blib/lib/HTML/Menu/TreeView.pm') or die "Cant set Document Root $! $/";
+my $file = '';
+while(<EDIT>) {
+        s/%PATH%/$path/;
+        $file .= $_;
+}
+seek(EDIT, 0, 0);
+print EDIT $file;
+truncate(EDIT, tell(EDIT));
+close(EDIT);
 
 1;
